searchData={"items":[{"type":"module","title":"BiMap","doc":"Bi-directional map implementation backed by two maps.\n\n> In computer science, a bidirectional map, or hash bag, is an associative data\n> structure in which the `(key, value)` pairs form a one-to-one correspondence.\n> Thus the binary relation is functional in each direction: `value` can also\n> act as a key to `key`. A pair `(a, b)` thus provides a unique coupling\n> between a `a` and `b` so that `b` can be found when `a` is used as a key and\n> `a` can be found when `b` is used as a key.\n>\n> ~[Wikipedia](https://en.wikipedia.org/wiki/Bidirectional_map)\n\nEntries in bimap do not follow any order.\n\nBiMaps do not impose any restriction on the key and value type: anything can be\na key in a bimap, and also anything can be a value. As a bidirectional\nkey-value structure, bimaps do not allow duplicated keys and values. This means\nit is not possible to store `[(A, B), (A, C)]` or `[(X, Z), (Y, Z)]` in\nthe bimap. If you need to lift this restriction to only not allowing duplicated\nkey-value pairs, check out `BiMultiMap`.\n\nKeys and values are compared using the exact-equality operator (`===`).","ref":"BiMap.html"},{"type":"module","title":"Example - BiMap","doc":"iex> bm = BiMap.new(a: 1, b: 2)\n    BiMap.new([a: 1, b: 2])\n    iex> BiMap.get(bm, :a)\n    1\n    iex> BiMap.get_key(bm, 2)\n    :b\n    iex> BiMap.put(bm, :a, 3)\n    BiMap.new([a: 3, b: 2])\n    iex> BiMap.put(bm, :c, 2)\n    BiMap.new([a: 1, c: 2])","ref":"BiMap.html#module-example"},{"type":"module","title":"Protocols - BiMap","doc":"`BiMap` implements `Enumerable`, `Collectable` and `Inspect` protocols.","ref":"BiMap.html#module-protocols"},{"type":"function","title":"BiMap.delete/2","doc":"Convenience shortcut for `delete/3`.","ref":"BiMap.html#delete/2"},{"type":"function","title":"BiMap.delete/3","doc":"Deletes `{key, value}` pair from `bimap`.\n\nIf the `key` does not exist, or `value` does not match, returns `bimap`\nunchanged.","ref":"BiMap.html#delete/3"},{"type":"function","title":"Examples - BiMap.delete/3","doc":"iex> bimap = BiMap.new([a: 1, b: 2])\n    iex> BiMap.delete(bimap, :b, 2)\n    BiMap.new([a: 1])\n    iex> BiMap.delete(bimap, :c, 3)\n    BiMap.new([a: 1, b: 2])\n    iex> BiMap.delete(bimap, :b, 3)\n    BiMap.new([a: 1, b: 2])","ref":"BiMap.html#delete/3-examples"},{"type":"function","title":"BiMap.delete_key/2","doc":"Deletes `{key, _}` pair from `bimap`.\n\nIf the `key` does not exist, returns `bimap` unchanged.","ref":"BiMap.html#delete_key/2"},{"type":"function","title":"Examples - BiMap.delete_key/2","doc":"iex> bimap = BiMap.new([a: 1, b: 2])\n    iex> BiMap.delete_key(bimap, :b)\n    BiMap.new([a: 1])\n    iex> BiMap.delete_key(bimap, :c)\n    BiMap.new([a: 1, b: 2])","ref":"BiMap.html#delete_key/2-examples"},{"type":"function","title":"BiMap.delete_value/2","doc":"Deletes `{_, value}` pair from `bimap`.\n\nIf the `value` does not exist, returns `bimap` unchanged.","ref":"BiMap.html#delete_value/2"},{"type":"function","title":"Examples - BiMap.delete_value/2","doc":"iex> bimap = BiMap.new([a: 1, b: 2])\n    iex> BiMap.delete_value(bimap, 2)\n    BiMap.new([a: 1])\n    iex> BiMap.delete_value(bimap, 3)\n    BiMap.new([a: 1, b: 2])","ref":"BiMap.html#delete_value/2-examples"},{"type":"function","title":"BiMap.equal?/2","doc":"Checks if two bimaps are equal.\n\nTwo bimaps are considered to be equal if they contain the same keys and those\nkeys contain the same values.","ref":"BiMap.html#equal?/2"},{"type":"function","title":"Examples - BiMap.equal?/2","doc":"iex> Map.equal?(BiMap.new([a: 1, b: 2]), BiMap.new([b: 2, a: 1]))\n    true\n    iex> Map.equal?(BiMap.new([a: 1, b: 2]), BiMap.new([b: 1, a: 2]))\n    false","ref":"BiMap.html#equal?/2-examples"},{"type":"function","title":"BiMap.fetch/2","doc":"Fetches the value for specific `key` in `bimap`\n\nIf `key` is present in `bimap` with value `value`, then `{:ok, value}` is\nreturned. Otherwise, `:error` is returned.","ref":"BiMap.html#fetch/2"},{"type":"function","title":"Examples - BiMap.fetch/2","doc":"iex> BiMap.fetch(BiMap.new(), :a)\n    :error\n    iex> bimap = BiMap.new([a: 1])\n    iex> BiMap.fetch(bimap, :a)\n    {:ok, 1}\n    iex> BiMap.fetch(bimap, :b)\n    :error","ref":"BiMap.html#fetch/2-examples"},{"type":"function","title":"BiMap.fetch!/2","doc":"Fetches the value for specific `key` in `bimap`.\n\nRaises `ArgumentError` if the key is absent.","ref":"BiMap.html#fetch!/2"},{"type":"function","title":"Examples - BiMap.fetch!/2","doc":"iex> bimap = BiMap.new([a: 1])\n    iex> BiMap.fetch!(bimap, :a)\n    1","ref":"BiMap.html#fetch!/2-examples"},{"type":"function","title":"BiMap.fetch_key/2","doc":"Fetches the key for specific `value` in `bimap`\n\nThis function is exact mirror of `fetch/2`.","ref":"BiMap.html#fetch_key/2"},{"type":"function","title":"Examples - BiMap.fetch_key/2","doc":"iex> BiMap.fetch_key(BiMap.new, 1)\n    :error\n    iex> bimap = BiMap.new([a: 1])\n    iex> BiMap.fetch_key(bimap, 1)\n    {:ok, :a}\n    iex> BiMap.fetch_key(bimap, 2)\n    :error","ref":"BiMap.html#fetch_key/2-examples"},{"type":"function","title":"BiMap.fetch_key!/2","doc":"Fetches the key for specific `value` in `bimap`.\n\nRaises `ArgumentError` if the value is absent. This function is exact mirror of `fetch!/2`.","ref":"BiMap.html#fetch_key!/2"},{"type":"function","title":"Examples - BiMap.fetch_key!/2","doc":"iex> bimap = BiMap.new([a: 1])\n    iex> BiMap.fetch_key!(bimap, 1)\n    :a","ref":"BiMap.html#fetch_key!/2-examples"},{"type":"function","title":"BiMap.get/3","doc":"Gets the value for specific `key` in `bimap`\n\nIf `key` is present in `bimap` with value `value`, then `value` is returned.\nOtherwise, `default` is returned (which is `nil` unless specified otherwise).","ref":"BiMap.html#get/3"},{"type":"function","title":"Examples - BiMap.get/3","doc":"iex> BiMap.get(BiMap.new(), :a)\n    nil\n    iex> bimap = BiMap.new([a: 1])\n    iex> BiMap.get(bimap, :a)\n    1\n    iex> BiMap.get(bimap, :b)\n    nil\n    iex> BiMap.get(bimap, :b, 3)\n    3","ref":"BiMap.html#get/3-examples"},{"type":"function","title":"BiMap.get_key/3","doc":"Gets the key for specific `value` in `bimap`\n\nThis function is exact mirror of `get/3`.","ref":"BiMap.html#get_key/3"},{"type":"function","title":"Examples - BiMap.get_key/3","doc":"iex> BiMap.get_key(BiMap.new, 1)\n    nil\n    iex> bimap = BiMap.new([a: 1])\n    iex> BiMap.get_key(bimap, 1)\n    :a\n    iex> BiMap.get_key(bimap, 2)\n    nil\n    iex> BiMap.get_key(bimap, 2, :b)\n    :b","ref":"BiMap.html#get_key/3-examples"},{"type":"function","title":"BiMap.has_key?/2","doc":"Checks if `bimap` contains `key`.","ref":"BiMap.html#has_key?/2"},{"type":"function","title":"Examples - BiMap.has_key?/2","doc":"iex> bimap = BiMap.new([a: \"foo\", b: \"bar\"])\n    iex> BiMap.has_key?(bimap, :a)\n    true\n    iex> BiMap.has_key?(bimap, :x)\n    false","ref":"BiMap.html#has_key?/2-examples"},{"type":"function","title":"BiMap.has_value?/2","doc":"Checks if `bimap` contains `value`.","ref":"BiMap.html#has_value?/2"},{"type":"function","title":"Examples - BiMap.has_value?/2","doc":"iex> bimap = BiMap.new([a: \"foo\", b: \"bar\"])\n    iex> BiMap.has_value?(bimap, \"foo\")\n    true\n    iex> BiMap.has_value?(bimap, \"moo\")\n    false","ref":"BiMap.html#has_value?/2-examples"},{"type":"function","title":"BiMap.keys/1","doc":"Returns all keys from `bimap`.","ref":"BiMap.html#keys/1"},{"type":"function","title":"Examples - BiMap.keys/1","doc":"iex> bimap = BiMap.new([a: 1, b: 2])\n    iex> BiMap.keys(bimap)\n    [:a, :b]","ref":"BiMap.html#keys/1-examples"},{"type":"function","title":"BiMap.left/1","doc":"Returns `key ➜ value` mapping of `bimap`.","ref":"BiMap.html#left/1"},{"type":"function","title":"Examples - BiMap.left/1","doc":"iex> bimap = BiMap.new([a: \"foo\", b: \"bar\"])\n    iex> BiMap.left(bimap)\n    %{a: \"foo\", b: \"bar\"}","ref":"BiMap.html#left/1-examples"},{"type":"function","title":"BiMap.member?/2","doc":"Convenience shortcut for `member?/3`.","ref":"BiMap.html#member?/2"},{"type":"function","title":"BiMap.member?/3","doc":"Checks if `bimap` contains `{key, value}` pair.","ref":"BiMap.html#member?/3"},{"type":"function","title":"Examples - BiMap.member?/3","doc":"iex> bimap = BiMap.new([a: \"foo\", b: \"bar\"])\n    iex> BiMap.member?(bimap, :a, \"foo\")\n    true\n    iex> BiMap.member?(bimap, :a, \"bar\")\n    false","ref":"BiMap.html#member?/3-examples"},{"type":"function","title":"BiMap.new/0","doc":"Creates a new bimap.","ref":"BiMap.html#new/0"},{"type":"function","title":"Examples - BiMap.new/0","doc":"iex> BiMap.new\n    BiMap.new([])","ref":"BiMap.html#new/0-examples"},{"type":"function","title":"BiMap.new/1","doc":"Creates a bimap from `enumerable` of key-value pairs.\n\nDuplicated pairs are removed; the latest one prevails.","ref":"BiMap.html#new/1"},{"type":"function","title":"Examples - BiMap.new/1","doc":"iex> BiMap.new([a: \"foo\", b: \"bar\"])\n    BiMap.new([a: \"foo\", b: \"bar\"])","ref":"BiMap.html#new/1-examples"},{"type":"function","title":"BiMap.new/2","doc":"Creates a bimap from `enumerable` via transform function returning key-value\npairs.","ref":"BiMap.html#new/2"},{"type":"function","title":"Examples - BiMap.new/2","doc":"iex> BiMap.new([1, 2, 1], fn x -> {x, x * 2} end)\n    BiMap.new([{1, 2}, {2, 4}])","ref":"BiMap.html#new/2-examples"},{"type":"function","title":"BiMap.put/2","doc":"Convenience shortcut for `put/3`","ref":"BiMap.html#put/2"},{"type":"function","title":"BiMap.put/3","doc":"Inserts `{key, value}` pair into `bimap`.\n\nIf either `key` or `value` is already in `bimap`, any overlapping bindings are\ndeleted.","ref":"BiMap.html#put/3"},{"type":"function","title":"Examples - BiMap.put/3","doc":"iex> bimap = BiMap.new\n    BiMap.new([])\n    iex> bimap = BiMap.put(bimap, :a, 0)\n    BiMap.new([a: 0])\n    iex> bimap = BiMap.put(bimap, :a, 1)\n    BiMap.new([a: 1])\n    iex> BiMap.put(bimap, :b, 1)\n    BiMap.new([b: 1])","ref":"BiMap.html#put/3-examples"},{"type":"function","title":"BiMap.put_new_key/3","doc":"Inserts `{key, value}` pair into `bimap` if `key` is not already in `bimap`.\n\nIf `key` already exists in `bimap`, `bimap` is returned unchanged.\n\nIf `key` does not exist and `value` is already in `bimap`, any overlapping bindings are\ndeleted.","ref":"BiMap.html#put_new_key/3"},{"type":"function","title":"Examples - BiMap.put_new_key/3","doc":"iex> bimap = BiMap.new\n    BiMap.new([])\n    iex> bimap = BiMap.put_new_key(bimap, :a, 0)\n    BiMap.new([a: 0])\n    iex> bimap = BiMap.put_new_key(bimap, :a, 1)\n    BiMap.new([a: 0])\n    iex> BiMap.put_new_key(bimap, :b, 1)\n    BiMap.new([a: 0, b: 1])\n    iex> BiMap.put_new_key(bimap, :c, 1)\n    BiMap.new([a: 0, c: 1])","ref":"BiMap.html#put_new_key/3-examples"},{"type":"function","title":"BiMap.put_new_value/3","doc":"Inserts `{key, value}` pair into `bimap` if `value` is not already in `bimap`.\n\nIf `value` already exists in `bimap`, `bimap` is returned unchanged.\n\nIf `value` does not exist and `key` is already in `bimap`, any overlapping bindings are\ndeleted.","ref":"BiMap.html#put_new_value/3"},{"type":"function","title":"Examples - BiMap.put_new_value/3","doc":"iex> bimap = BiMap.new\n    BiMap.new([])\n    iex> bimap = BiMap.put_new_value(bimap, :a, 0)\n    BiMap.new([a: 0])\n    iex> bimap = BiMap.put_new_value(bimap, :a, 1)\n    BiMap.new([a: 1])\n    iex> BiMap.put_new_value(bimap, :b, 1)\n    BiMap.new([a: 1])\n    iex> BiMap.put_new_value(bimap, :c, 2)\n    BiMap.new([a: 1, c: 2])","ref":"BiMap.html#put_new_value/3-examples"},{"type":"function","title":"BiMap.right/1","doc":"Returns `value ➜ key` mapping of `bimap`.","ref":"BiMap.html#right/1"},{"type":"function","title":"Examples - BiMap.right/1","doc":"iex> bimap = BiMap.new([a: \"foo\", b: \"bar\"])\n    iex> BiMap.right(bimap)\n    %{\"foo\" => :a, \"bar\" => :b}","ref":"BiMap.html#right/1-examples"},{"type":"function","title":"BiMap.size/1","doc":"Returns the number of elements in `bimap`.\n\nThe size of a bimap is the number of key-value pairs that the map contains.","ref":"BiMap.html#size/1"},{"type":"function","title":"Examples - BiMap.size/1","doc":"iex> BiMap.size(BiMap.new)\n    0\n\n    iex> bimap = BiMap.new([a: \"foo\", b: \"bar\"])\n    iex> BiMap.size(bimap)\n    2","ref":"BiMap.html#size/1-examples"},{"type":"function","title":"BiMap.to_list/1","doc":"Returns list of unique key-value pairs in `bimap`.","ref":"BiMap.html#to_list/1"},{"type":"function","title":"Examples - BiMap.to_list/1","doc":"iex> bimap = BiMap.new([a: \"foo\", b: \"bar\"])\n    iex> BiMap.to_list(bimap)\n    [a: \"foo\", b: \"bar\"]","ref":"BiMap.html#to_list/1-examples"},{"type":"function","title":"BiMap.values/1","doc":"Returns all values from `bimap`.","ref":"BiMap.html#values/1"},{"type":"function","title":"Examples - BiMap.values/1","doc":"iex> bimap = BiMap.new([a: 1, b: 2])\n    iex> BiMap.values(bimap)\n    [1, 2]","ref":"BiMap.html#values/1-examples"},{"type":"type","title":"BiMap.k/0","doc":"Key type","ref":"BiMap.html#t:k/0"},{"type":"type","title":"BiMap.t/0","doc":"","ref":"BiMap.html#t:t/0"},{"type":"type","title":"BiMap.t/2","doc":"","ref":"BiMap.html#t:t/2"},{"type":"type","title":"BiMap.v/0","doc":"Value type","ref":"BiMap.html#t:v/0"},{"type":"module","title":"BiMultiMap","doc":"Bi-directional multimap implementation backed by two multimaps.\n\nEntries in bimap do not follow any order.\n\nBiMultiMaps do not impose any restriction on the key and value type: anything\ncan be a key in a bimap, and also anything can be a value.\n\nBiMultiMaps differ from `BiMap`s by disallowing duplicates only among key-value\npairs, not among keys and values separately. This means it is possible to store\n`[(A, B), (A, C)]` or `[(X, Z), (Y, Z)]` in BiMultiMap.\n\nKeys and values are compared using the exact-equality operator (`===`).","ref":"BiMultiMap.html"},{"type":"module","title":"Example - BiMultiMap","doc":"iex> mm = BiMultiMap.new(a: 1, b: 2, b: 1)\n    BiMultiMap.new([a: 1, b: 1, b: 2])\n    iex> BiMultiMap.get(mm, :a)\n    [1]\n    iex> BiMultiMap.get_keys(mm, 1)\n    [:a, :b]\n    iex> BiMultiMap.put(mm, :a, 3)\n    BiMultiMap.new([a: 1, a: 3, b: 1, b: 2])","ref":"BiMultiMap.html#module-example"},{"type":"module","title":"Protocols - BiMultiMap","doc":"`BiMultiMap` implements `Enumerable`, `Collectable` and `Inspect` protocols.","ref":"BiMultiMap.html#module-protocols"},{"type":"function","title":"BiMultiMap.delete/2","doc":"Convenience shortcut for `delete/3`.","ref":"BiMultiMap.html#delete/2"},{"type":"function","title":"BiMultiMap.delete/3","doc":"Deletes `{key, value}` pair from `bimultimap`.\n\nIf the `key` does not exist, or `value` does not match, returns `bimultimap`\nunchanged.","ref":"BiMultiMap.html#delete/3"},{"type":"function","title":"Examples - BiMultiMap.delete/3","doc":"iex> bimultimap = BiMultiMap.new([a: 1, b: 2, c: 2])\n    iex> BiMultiMap.delete(bimultimap, :b, 2)\n    BiMultiMap.new([a: 1, c: 2])\n    iex> BiMultiMap.delete(bimultimap, :c, 3)\n    BiMultiMap.new([a: 1, b: 2, c: 2])","ref":"BiMultiMap.html#delete/3-examples"},{"type":"function","title":"BiMultiMap.delete_key/2","doc":"Deletes `{key, _}` pair from `bimultimap`.\n\nIf the `key` does not exist, returns `bimultimap` unchanged.","ref":"BiMultiMap.html#delete_key/2"},{"type":"function","title":"Examples - BiMultiMap.delete_key/2","doc":"iex> bimultimap = BiMultiMap.new([a: 1, b: 2, b: 3])\n    iex> BiMultiMap.delete_key(bimultimap, :b)\n    BiMultiMap.new([a: 1])\n    iex> BiMultiMap.delete_key(bimultimap, :c)\n    BiMultiMap.new([a: 1, b: 2, b: 3])","ref":"BiMultiMap.html#delete_key/2-examples"},{"type":"function","title":"BiMultiMap.delete_value/2","doc":"Deletes `{_, value}` pair from `bimultimap`.\n\nIf the `value` does not exist, returns `bimultimap` unchanged.","ref":"BiMultiMap.html#delete_value/2"},{"type":"function","title":"Examples - BiMultiMap.delete_value/2","doc":"iex> bimultimap = BiMultiMap.new([a: 1, b: 2, c: 1])\n    iex> BiMultiMap.delete_value(bimultimap, 1)\n    BiMultiMap.new([b: 2])\n    iex> BiMultiMap.delete_value(bimultimap, 3)\n    BiMultiMap.new([a: 1, b: 2, c: 1])","ref":"BiMultiMap.html#delete_value/2-examples"},{"type":"function","title":"BiMultiMap.equal?/2","doc":"Checks if two bimultimaps are equal.\n\nTwo bimultimaps are considered to be equal if they contain the same keys and\nthose keys are bound with the same values.","ref":"BiMultiMap.html#equal?/2"},{"type":"function","title":"Examples - BiMultiMap.equal?/2","doc":"iex> Map.equal?(BiMultiMap.new([a: 1, b: 2, b: 3]), BiMultiMap.new([b: 2, b: 3, a: 1]))\n    true\n    iex> Map.equal?(BiMultiMap.new([a: 1, b: 2, b: 3]), BiMultiMap.new([b: 1, b: 3, a: 2]))\n    false","ref":"BiMultiMap.html#equal?/2-examples"},{"type":"function","title":"BiMultiMap.fetch/2","doc":"Fetches all values for specific `key` in `bimultimap`\n\nIf `key` is present in `bimultimap` with values `values`, then `{:ok, values}`\nis returned. Otherwise, `:error` is returned.","ref":"BiMultiMap.html#fetch/2"},{"type":"function","title":"Examples - BiMultiMap.fetch/2","doc":"iex> BiMultiMap.fetch(BiMultiMap.new(), :a)\n    :error\n    iex> bimultimap = BiMultiMap.new([a: 1, c: 1, c: 2])\n    iex> BiMultiMap.fetch(bimultimap, :a)\n    {:ok, [1]}\n    iex> BiMultiMap.fetch(bimultimap, :b)\n    :error\n    iex> BiMultiMap.fetch(bimultimap, :c)\n    {:ok, [1, 2]}","ref":"BiMultiMap.html#fetch/2-examples"},{"type":"function","title":"BiMultiMap.fetch!/2","doc":"Fetches all values for specific `key` in `bimultimap`\n\nRaises `ArgumentError` if the key is absent.","ref":"BiMultiMap.html#fetch!/2"},{"type":"function","title":"Examples - BiMultiMap.fetch!/2","doc":"iex> bimultimap = BiMultiMap.new([a: 1, c: 1, c: 2])\n    iex> BiMultiMap.fetch!(bimultimap, :a)\n    [1]\n    iex> BiMultiMap.fetch!(bimultimap, :c)\n    [1, 2]","ref":"BiMultiMap.html#fetch!/2-examples"},{"type":"function","title":"BiMultiMap.fetch_keys/2","doc":"Fetches all keys for specific `value` in `bimultimap`\n\nThis function is exact mirror of `fetch/2`.","ref":"BiMultiMap.html#fetch_keys/2"},{"type":"function","title":"Examples - BiMultiMap.fetch_keys/2","doc":"iex> BiMultiMap.fetch_keys(BiMultiMap.new, 1)\n    :error\n    iex> bimultimap = BiMultiMap.new([a: 1, c: 3, d: 3])\n    iex> BiMultiMap.fetch_keys(bimultimap, 1)\n    {:ok, [:a]}\n    iex> BiMultiMap.fetch_keys(bimultimap, 2)\n    :error\n    iex> BiMultiMap.fetch_keys(bimultimap, 3)\n    {:ok, [:c, :d]}","ref":"BiMultiMap.html#fetch_keys/2-examples"},{"type":"function","title":"BiMultiMap.fetch_keys!/2","doc":"Fetches all keys for specific `value` in `bimultimap`\n\nRaises `ArgumentError` if the key is absent. This function is exact mirror of `fetch!/2`.","ref":"BiMultiMap.html#fetch_keys!/2"},{"type":"function","title":"Examples - BiMultiMap.fetch_keys!/2","doc":"iex> bimultimap = BiMultiMap.new([a: 1, c: 3, d: 3])\n    iex> BiMultiMap.fetch_keys!(bimultimap, 1)\n    [:a]\n    iex> BiMultiMap.fetch_keys!(bimultimap, 3)\n    [:c, :d]","ref":"BiMultiMap.html#fetch_keys!/2-examples"},{"type":"function","title":"BiMultiMap.get/3","doc":"Gets all values for specific `key` in `bimultimap`\n\nIf `key` is present in `bimultimap` with values `values`, then `values` are\nreturned. Otherwise, `default` is returned (which is `[]` unless specified\notherwise).","ref":"BiMultiMap.html#get/3"},{"type":"function","title":"Examples - BiMultiMap.get/3","doc":"iex> BiMultiMap.get(BiMultiMap.new(), :a)\n    []\n    iex> bimultimap = BiMultiMap.new([a: 1, c: 1, c: 2])\n    iex> BiMultiMap.get(bimultimap, :a)\n    [1]\n    iex> BiMultiMap.get(bimultimap, :b)\n    []\n    iex> BiMultiMap.get(bimultimap, :b, 3)\n    3\n    iex> BiMultiMap.get(bimultimap, :c)\n    [1, 2]","ref":"BiMultiMap.html#get/3-examples"},{"type":"function","title":"BiMultiMap.get_keys/3","doc":"Gets all keys for specific `value` in `bimultimap`\n\nThis function is exact mirror of `get/3`.","ref":"BiMultiMap.html#get_keys/3"},{"type":"function","title":"Examples - BiMultiMap.get_keys/3","doc":"iex> BiMultiMap.get_keys(BiMultiMap.new, 1)\n    []\n    iex> bimultimap = BiMultiMap.new([a: 1, c: 3, d: 3])\n    iex> BiMultiMap.get_keys(bimultimap, 1)\n    [:a]\n    iex> BiMultiMap.get_keys(bimultimap, 2)\n    []\n    iex> BiMultiMap.get_keys(bimultimap, 2, :b)\n    :b\n    iex> BiMultiMap.get_keys(bimultimap, 3)\n    [:c, :d]","ref":"BiMultiMap.html#get_keys/3-examples"},{"type":"function","title":"BiMultiMap.has_key?/2","doc":"Checks if `bimultimap` contains `key`.","ref":"BiMultiMap.html#has_key?/2"},{"type":"function","title":"Examples - BiMultiMap.has_key?/2","doc":"iex> bimultimap = BiMultiMap.new([a: \"foo\", b: \"bar\"])\n    iex> BiMultiMap.has_key?(bimultimap, :a)\n    true\n    iex> BiMultiMap.has_key?(bimultimap, :x)\n    false","ref":"BiMultiMap.html#has_key?/2-examples"},{"type":"function","title":"BiMultiMap.has_value?/2","doc":"Checks if `bimultimap` contains `value`.","ref":"BiMultiMap.html#has_value?/2"},{"type":"function","title":"Examples - BiMultiMap.has_value?/2","doc":"iex> bimultimap = BiMultiMap.new([a: \"foo\", b: \"bar\"])\n    iex> BiMultiMap.has_value?(bimultimap, \"foo\")\n    true\n    iex> BiMultiMap.has_value?(bimultimap, \"moo\")\n    false","ref":"BiMultiMap.html#has_value?/2-examples"},{"type":"function","title":"BiMultiMap.keys/1","doc":"Returns all unique keys from `bimultimap`.","ref":"BiMultiMap.html#keys/1"},{"type":"function","title":"Examples - BiMultiMap.keys/1","doc":"iex> bimultimap = BiMultiMap.new([a: 1, b: 2, b: 3])\n    iex> BiMultiMap.keys(bimultimap)\n    [:a, :b]","ref":"BiMultiMap.html#keys/1-examples"},{"type":"function","title":"BiMultiMap.left/1","doc":"Returns `key ➜ [value]` mapping of `bimultimap`.","ref":"BiMultiMap.html#left/1"},{"type":"function","title":"Examples - BiMultiMap.left/1","doc":"iex> bimultimap = BiMultiMap.new([a: \"foo\", b: \"bar\", b: \"moo\"])\n    iex> BiMultiMap.left(bimultimap)\n    %{a: [\"foo\"], b: [\"bar\", \"moo\"]}","ref":"BiMultiMap.html#left/1-examples"},{"type":"function","title":"BiMultiMap.member?/2","doc":"Convenience shortcut for `member?/3`.","ref":"BiMultiMap.html#member?/2"},{"type":"function","title":"BiMultiMap.member?/3","doc":"Checks if `bimultimap` contains `{key, value}` pair.","ref":"BiMultiMap.html#member?/3"},{"type":"function","title":"Examples - BiMultiMap.member?/3","doc":"iex> bimultimap = BiMultiMap.new([a: \"foo\", a: \"moo\", b: \"bar\"])\n    iex> BiMultiMap.member?(bimultimap, :a, \"foo\")\n    true\n    iex> BiMultiMap.member?(bimultimap, :a, \"moo\")\n    true\n    iex> BiMultiMap.member?(bimultimap, :a, \"bar\")\n    false","ref":"BiMultiMap.html#member?/3-examples"},{"type":"function","title":"BiMultiMap.new/0","doc":"Creates a new bimultimap.","ref":"BiMultiMap.html#new/0"},{"type":"function","title":"Examples - BiMultiMap.new/0","doc":"iex> BiMultiMap.new\n    BiMultiMap.new([])","ref":"BiMultiMap.html#new/0-examples"},{"type":"function","title":"BiMultiMap.new/1","doc":"Creates a bimultimap from `enumerable` of key-value pairs.\n\nDuplicated pairs are removed; the latest one prevails.","ref":"BiMultiMap.html#new/1"},{"type":"function","title":"Examples - BiMultiMap.new/1","doc":"iex> BiMultiMap.new([a: 1, a: 2])\n    BiMultiMap.new([a: 1, a: 2])","ref":"BiMultiMap.html#new/1-examples"},{"type":"function","title":"BiMultiMap.new/2","doc":"Creates a bimultimap from `enumerable` via transform function returning\nkey-value pairs.","ref":"BiMultiMap.html#new/2"},{"type":"function","title":"Examples - BiMultiMap.new/2","doc":"iex> BiMultiMap.new([1, 2, 1], fn x -> {x, x * 2} end)\n    BiMultiMap.new([{1, 2}, {2, 4}])","ref":"BiMultiMap.html#new/2-examples"},{"type":"function","title":"BiMultiMap.put/2","doc":"Convenience shortcut for `put/3`","ref":"BiMultiMap.html#put/2"},{"type":"function","title":"BiMultiMap.put/3","doc":"Inserts `{key, value}` pair into `bimultimap`.\n\nIf `{key, value}` is already in `bimultimap`, it is deleted.","ref":"BiMultiMap.html#put/3"},{"type":"function","title":"Examples - BiMultiMap.put/3","doc":"iex> bimultimap = BiMultiMap.new\n    BiMultiMap.new([])\n    iex> bimultimap = BiMultiMap.put(bimultimap, :a, 1)\n    BiMultiMap.new([a: 1])\n    iex> bimultimap = BiMultiMap.put(bimultimap, :a, 2)\n    BiMultiMap.new([a: 1, a: 2])\n    iex> BiMultiMap.put(bimultimap, :b, 2)\n    BiMultiMap.new([a: 1, a: 2, b: 2])","ref":"BiMultiMap.html#put/3-examples"},{"type":"function","title":"BiMultiMap.right/1","doc":"Returns `value ➜ key` mapping of `bimultimap`.","ref":"BiMultiMap.html#right/1"},{"type":"function","title":"Examples - BiMultiMap.right/1","doc":"iex> bimultimap = BiMultiMap.new([a: \"foo\", b: \"bar\", c: \"bar\"])\n    iex> BiMultiMap.right(bimultimap)\n    %{\"foo\" => [:a], \"bar\" => [:b, :c]}","ref":"BiMultiMap.html#right/1-examples"},{"type":"function","title":"BiMultiMap.size/1","doc":"Returns the number of elements in `bimultimap`.\n\nThe size of a bimultimap is the number of key-value pairs that the map\ncontains.","ref":"BiMultiMap.html#size/1"},{"type":"function","title":"Examples - BiMultiMap.size/1","doc":"iex> BiMultiMap.size(BiMultiMap.new)\n    0\n\n    iex> bimultimap = BiMultiMap.new([a: \"foo\", a: \"bar\"])\n    iex> BiMultiMap.size(bimultimap)\n    2","ref":"BiMultiMap.html#size/1-examples"},{"type":"function","title":"BiMultiMap.to_list/1","doc":"Returns list of unique key-value pairs in `bimultimap`.","ref":"BiMultiMap.html#to_list/1"},{"type":"function","title":"Examples - BiMultiMap.to_list/1","doc":"iex> bimultimap = BiMultiMap.new([a: \"foo\", b: \"bar\"])\n    iex> BiMultiMap.to_list(bimultimap)\n    [a: \"foo\", b: \"bar\"]","ref":"BiMultiMap.html#to_list/1-examples"},{"type":"function","title":"BiMultiMap.values/1","doc":"Returns all unique values from `bimultimap`.","ref":"BiMultiMap.html#values/1"},{"type":"function","title":"Examples - BiMultiMap.values/1","doc":"iex> bimultimap = BiMultiMap.new([a: 1, b: 2, c: 2])\n    iex> BiMultiMap.values(bimultimap)\n    [1, 2]","ref":"BiMultiMap.html#values/1-examples"},{"type":"type","title":"BiMultiMap.k/0","doc":"Key type","ref":"BiMultiMap.html#t:k/0"},{"type":"type","title":"BiMultiMap.t/0","doc":"","ref":"BiMultiMap.html#t:t/0"},{"type":"type","title":"BiMultiMap.t/2","doc":"","ref":"BiMultiMap.html#t:t/2"},{"type":"type","title":"BiMultiMap.v/0","doc":"Value type","ref":"BiMultiMap.html#t:v/0"},{"type":"extras","title":"BiMap","doc":"# BiMap\n\n[![Version](https://img.shields.io/hexpm/v/bimap.svg)](https://hex.pm/packages/bimap)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/bimap/)\n\nElixir implementation of bidirectional map (`BiMap`) and multimap (`BiMultiMap`).","ref":"readme.html"},{"type":"extras","title":"Installation - BiMap","doc":"The package can be installed by adding `bimap` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:bimap, \"~> 1.3\"}]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Getting started - BiMap","doc":"For more examples, checkout [`BiMap`](https://hexdocs.pm/bimap/BiMap.html) and [`BiMultiMap`](https://hexdocs.pm/bimap/BiMultiMap.html) on hex docs.\n\n#","ref":"readme.html#getting-started"},{"type":"extras","title":"BiMap - BiMap","doc":"```elixir\niex(1)> Mix.install [:bimap]\niex(2)> bm = BiMap.new(a: 1, b: 2)\nBiMap.new([a: 1, b: 2])\niex(3)> BiMap.get(bm, :a)\n1\niex(4)> BiMap.get_key(bm, 2)\n:b\niex(5)> BiMap.put(bm, :a, 3)\nBiMap.new([a: 3, b: 2])\niex(6)> BiMap.put(bm, :c, 2)\nBiMap.new([a: 1, c: 2])\n```\n\n#","ref":"readme.html#bimap"},{"type":"extras","title":"BiMultiMap - BiMap","doc":"```elixir\niex(1)> Mix.install [:bimap]\niex(2)> mm = BiMultiMap.new(a: 1, b: 2, b: 1)\nBiMultiMap.new([a: 1, b: 1, b: 2])\niex(3)> BiMultiMap.get(mm, :a)\n[1]\niex(4)> BiMultiMap.get_keys(mm, 1)\n[:a, :b]\niex(5)> BiMultiMap.put(mm, :a, 3)\nBiMultiMap.new([a: 1, a: 3, b: 1, b: 2])\n```","ref":"readme.html#bimultimap"},{"type":"extras","title":"Changelog - BiMap","doc":"All notable changes to this project are documented on the [GitHub releases] page.","ref":"readme.html#changelog"},{"type":"extras","title":"License - BiMap","doc":"See the [LICENSE] file for license rights and limitations (MIT).\n\n[github releases]: https://github.com/mkaput/elixir-bimap/releases\n[license]: https://github.com/mkaput/elixir-bimap/blob/master/LICENSE.txt","ref":"readme.html#license"}],"content_type":"text/markdown"}